@@ -1,7 +1,7 @@
 /*
  * test-arraylist.cpp - test arraylist functions
  *
- * Copyright (C) 2014-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2017 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -36,7 +36,7 @@ extern "C"
                               __result_index_insert, __value)           \
     pointer = arraylist_search (arraylist, (void *)(__value),           \
                                 &index, &index_insert);                 \
-    if (__result_ptr && pointer)                                        \
+    if (__result_ptr != NULL && pointer)                                \
     {                                                                   \
         STRCMP_EQUAL(__result_ptr, (const char *)pointer);              \
     }                                                                   \
@@ -65,6 +65,10 @@ int
 test_cmp_cb (void *data, struct t_arraylist *arraylist,
              void *pointer1, void *pointer2)
 {
+    /* make C++ compiler happy */
+    (void) data;
+    (void) arraylist;
+
     if (!pointer1 || !pointer2)
         return (pointer1) ? 1 : ((pointer2) ? -1 : 0);
 
@@ -75,7 +79,7 @@ void
 test_arraylist (int initial_size, int sorted, int allow_duplicates)
 {
     struct t_arraylist *arraylist;
-    int i, index, index_insert, expected_pos;
+    int i, index, index_insert;
     void *pointer;
     const char *item_aaa = "aaa";
     const char *item_abc = "abc";
@@ -485,8 +489,6 @@ TEST(Arraylist, New)
                    arraylist_new (-1, 0, 0, NULL, NULL, NULL, NULL));
     POINTERS_EQUAL(NULL,
                    arraylist_new (-1, 0, 0, &test_cmp_cb, NULL, NULL, NULL));
-    POINTERS_EQUAL(NULL,
-                   arraylist_new (0, 0, 0, NULL, NULL, NULL, NULL));
 
     /* tests on arraylists */
     for (initial_size = 0; initial_size < 2; initial_size++)
